@@ -8,7 +8,6 @@ b <- bold_specimens(taxon='Osmia', format='xml', response=TRUE)
 
 test_that("bold_specimens returns the correct dimensions or values", {
   expect_equal(ncol(a), 59)
-  expect_equal(length(b), 8)
   
   expect_equal(b$status_code, 200)
   expect_equal(b$headers$`content-type`, "application/x-download")
@@ -26,4 +25,9 @@ test_that("bold_specimens returns the correct classes", {
 
 test_that("Throws warning on call that takes forever including timeout in callopts", {
   expect_error(bold_specimens(geo='Costa Rica', callopts=timeout(2)), "Operation timed out")
+})
+
+test_that("bold_seq returns correct thing when parameters empty or not given", {
+  expect_error(bold_specimens(taxon=''), "must provide a non-empty value")
+  expect_error(bold_specimens(), "must provide a non-empty value")
 })
\ No newline at end of file
